==> xrayutilities_1.7.4.orig.tar.gz: xrayutilities-1.7.4/lib/xrayutilities/materials/__init__.py <==
# This file is part of xrayutilities.
#
# xrayutilities is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
# Copyright (C) 2009 Eugen Wintersberger <eugen.wintersberger@desy.de>
# Copyright (C) 2010-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
# Copyright (C) 2022 Vinícius Frehse <vinifrehse@gmail.com>

from . import elements
from .atom import Atom
from .cif import CIFFile, cifexport
from .database import (DataBase, add_f0_from_intertab, add_f0_from_xop,
                       add_f1f2_from_ascii_file, add_f1f2_from_henkedb,
                       add_f1f2_from_kissel, add_mass_from_NIST,
                       init_material_db)
from .material import (Alloy, Amorphous, Crystal, CubicAlloy,
                       CubicElasticTensor, MonoclinicElasticTensor,
                       TrigonalElasticTensor, HexagonalElasticTensor,
                       Material, PseudomorphicMaterial, WZTensorFromCub)
from .plot import show_reciprocal_space_plane
from .predefined_materials import *
from .spacegrouplattice import SGLattice, SymOp

==> xrayutilities_1.7.10.orig.tar.gz: xrayutilities-1.7.10/lib/xrayutilities/materials/__init__.py <==
# This file is part of xrayutilities.
#
# xrayutilities is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
# Copyright (C) 2009 Eugen Wintersberger <eugen.wintersberger@desy.de>
# Copyright (c) 2010-2020, 2023 Dominik Kriegner <dominik.kriegner@gmail.com>
# Copyright (C) 2022 Vinícius Frehse <vinifrehse@gmail.com>

from . import elements
from .atom import Atom
from .cif import CIFFile, cifexport
from .database import (DataBase, add_f0_from_intertab, add_f0_from_xop,
                       add_f1f2_from_ascii_file, add_f1f2_from_henkedb,
                       add_f1f2_from_kissel, add_mass_from_NIST,
                       init_material_db)
from .material import (Alloy, Amorphous, Crystal, CubicAlloy,
                       CubicElasticTensor, HexagonalElasticTensor, Material,
                       MonoclinicElasticTensor, PseudomorphicMaterial,
                       TrigonalElasticTensor, WZTensorFromCub)
from .plot import show_reciprocal_space_plane
from .predefined_materials import *  # noqa: F403
from .spacegrouplattice import SGLattice, SymOp
